Skip to contents

Small internal function for me that puts example IBD files and meta files into a folder to test spIBDer_app

Usage

copy_files(folder)

Arguments

folder

folder to place files

Value

copies files