Skip to contents

The fold changes are all based on comparison to reference level

Usage

get_ergm_fc(ergm, trim = TRUE)

Arguments

ergm

an ergm fit

trim

whether to remove coefficients where the coefficient is -Inf

Value

tibble of fold changes

Examples

ergm <- get_ergms(example_network, preds = "site", types = "nodemix")
#> Starting maximum pseudolikelihood estimation (MPLE):
#> Obtaining the responsible dyads.
#> Evaluating the predictor and response matrix.
#> Maximizing the pseudolikelihood.
#> Finished MPLE.
#> Evaluating log-likelihood at the estimate. 
#> 
#> Starting maximum pseudolikelihood estimation (MPLE):
#> Obtaining the responsible dyads.
#> Evaluating the predictor and response matrix.
#> Maximizing the pseudolikelihood.
#> Finished MPLE.
#> Evaluating log-likelihood at the estimate. 
#> 
get_ergm_fc(ergm[[1]])
#> # A tibble: 6 × 3
#>   term          theta   phi
#>   <chr>         <dbl> <dbl>
#> 1 edges        -1.76  1    
#> 2 mix.site.A.B -0.550 0.615
#> 3 mix.site.B.B  0.759 1.83 
#> 4 mix.site.A.C -0.913 0.440
#> 5 mix.site.B.C -0.841 0.471
#> 6 mix.site.C.C  1.35  2.72