Takes first letter of each word, where a word is separated by space on hyphen Also removes brackets first
Examples
abbreviate_terms(c("Jono Tuke", "Adam Ben Rohrlach", "Adelaide-University"))
#> [1] "JT" "ABR" "AU"
Takes first letter of each word, where a word is separated by space on hyphen Also removes brackets first
abbreviate_terms(c("Jono Tuke", "Adam Ben Rohrlach", "Adelaide-University"))
#> [1] "JT" "ABR" "AU"